unit untTopicPostThread;

interface

uses
  Classes, SysUtils, Dialogs, DzURL,
  untHttpClient, untStreamTool, untTool,
  untBBSCore, untBoard, untGlobal, untOption;

type

  TTopicPostThread = class(TThread)
  private
    FParent       : TOnlineBoard;
    FTitle        : string;
    FPostName     : string;
    FPostEmail    : string;
    FPostBody     : string;
    FTopicId      : string;
    FErrorMessage : string;
    FBoardStateType : TBoardStateType;
    procedure RaiseBoardStateChangeEvent;
  public
    procedure Execute; override;
    constructor Create(Parent: TOnlineBoard;TopicId, Title, PostName, PostEmail, PostBody : string);
  end;

implementation

{ TTopicPostThread }

constructor TTopicPostThread.Create(Parent: TOnlineBoard; TopicId, Title, PostName, PostEmail, PostBody : string);
begin
  inherited Create(true);

  FParent := Parent;
  FPostName  := PostName;
  FPostEmail := PostEmail;
  FPostBody  := PostBody;
  FTitle     := Title;
  FTopicId   := TopicId;
end;

procedure TTopicPostThread.Execute;
var
  sr           : TStreamReader;
  Response     : THttpResponse;
  line         : string;
  pagestr      : string;
  currenttime  : TDateTime;
  ErrorMsg     : string;
  HttpRequest  : THttpRequest;
  intTime      : integer;
begin
  inherited;

  // 
  HttpRequest := THttpRequest.Create(FParent.BbsCgiUrl);
  HttpRequest.Method  := 'POST';
  HttpRequest.Referer := FParent.BoardUrl;
  HttpRequest.UserAgent := APP_USERAGENT;
  HttpRequest.AddArgument('submit', '');
  HttpRequest.AddArgument('subject', FTitle);
  HttpRequest.AddArgument('FROM', FPostName);
  HttpRequest.AddArgument('mail', FPostEmail);
  HttpRequest.AddArgument('MESSAGE', FPostBody);
  HttpRequest.AddArgument('bbs', FParent.BoardId);

  intTime := Round((Now() - EncodeDate(1970, 1, 1)) * 86400);
  if FTopicId = '' then FTopicId := IntToStr(intTime);
  HttpRequest.AddArgument('key', FTopicId);
  HttpRequest.AddArgument('time', IntToStr(intTime));
  
  HttpRequest.AddCookie('NAME', FPostName);
  HttpRequest.AddCookie('MAIL', FPostEmail);

  Response := HttpRequest.GetResponse;

  if (Response.StatusCode >= 200) and
     (Response.StatusCode < 300) then
  begin
    sr := TStreamReader.Create(Response.GetResponseStream);
    pagestr := sr.ReadToEnd;
    HttpRequest.Close;

    if Pos('݂܂', pagestr) = 0 then
    begin
      ErrorMsg := CopyMiddle(pagestr, '<b>', '</b>');
      FErrorMessage := Errormsg;
    end;
  end;
  HttpRequest.Free;

  FParent.WriteError := FErrorMessage;
  FBoardStateType := bsWriteDone;
  Synchronize(RaiseBoardStateChangeEvent);

  Terminate;

  Free;

end;

procedure TTopicPostThread.RaiseBoardStateChangeEvent;
begin
  gBBSCore.RaiseBoardStateChangeEvent(FParent, FBoardStateType);
end;


end.
